==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GridColumnHideOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnHideOptionsDescription } from "./GridColumnHideOptionsDescription";
/**
 * @hidden
 */
var GridColumnHideOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnHideOptionsDescriptionMetadata, _super);
    function GridColumnHideOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnHideOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnHideOptionsDescriptionMetadata.a == null) {
            GridColumnHideOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnHideOptionsDescriptionMetadata.c(GridColumnHideOptionsDescriptionMetadata.a);
        }
        if (a.g(GridColumnHideOptionsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridColumnHideOptionsDescriptionMetadata.a);
    };
    GridColumnHideOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
    };
    GridColumnHideOptionsDescriptionMetadata.d = function (a) {
        GridColumnHideOptionsDescriptionMetadata.b(a);
        a.u("GridColumnHideOptions", function () { return new GridColumnHideOptionsDescription(); });
        a.t("GridColumnHideOptions", GridColumnHideOptionsDescriptionMetadata.a);
    };
    GridColumnHideOptionsDescriptionMetadata.$t = markType(GridColumnHideOptionsDescriptionMetadata, 'GridColumnHideOptionsDescriptionMetadata');
    GridColumnHideOptionsDescriptionMetadata.a = null;
    return GridColumnHideOptionsDescriptionMetadata;
}(Base));
export { GridColumnHideOptionsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GridColumnHideOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnHideOptionsDescription } from "./GridColumnHideOptionsDescription";
/**
 * @hidden
 */
var GridColumnHideOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnHideOptionsDescriptionMetadata, _super);
    function GridColumnHideOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnHideOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnHideOptionsDescriptionMetadata.a == null) {
            GridColumnHideOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnHideOptionsDescriptionMetadata.c(GridColumnHideOptionsDescriptionMetadata.a);
        }
        if (a.j(GridColumnHideOptionsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridColumnHideOptionsDescriptionMetadata.a);
    };
    GridColumnHideOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
    };
    GridColumnHideOptionsDescriptionMetadata.d = function (a) {
        GridColumnHideOptionsDescriptionMetadata.b(a);
        a.aa("GridColumnHideOptions", function () { return new GridColumnHideOptionsDescription(); });
        a.z("GridColumnHideOptions", GridColumnHideOptionsDescriptionMetadata.a);
    };
    GridColumnHideOptionsDescriptionMetadata.$t = markType(GridColumnHideOptionsDescriptionMetadata, 'GridColumnHideOptionsDescriptionMetadata');
    GridColumnHideOptionsDescriptionMetadata.a = null;
    return GridColumnHideOptionsDescriptionMetadata;
}(Base));
export { GridColumnHideOptionsDescriptionMetadata };
